/* This file is part of The_Merry_Turnip
 * 
 * The_Merry_Turnip - TODO: Description
 * Copyright © DAVY Guillaume 2009 <davyg2@gmail.com>
 * 
 * The_Merry_Turnip is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * The_Merry_Turnip is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/*!	\file base.cpp
	\brief Implement base class
*/

#include <game.h>

/*!
	\class base
	Contain some basic feature needed by a lot of class.\n
	This class handle more precisly the id, the name and the log function.\n
	Derive from IEventReceiver, in order to be able to "surcharger" OnEvent()
	to handle events.
*/

/** Construct the base initiate base::nameClass to name and base::initialize to false 
	\param name Name of the class(needed for logging) */
base::base(stringc name)
{
	nameClass = name;
	initialize = false;
}

base::~base()
{
	
}

/** Put base::mycore to c, base::id to Id, init the logger and put initialized to true
	\param Id Id of the class
	\param c Pointer to the core
	\return The id of the log (base::logId)*/
int base::init(int Id, coeur* c)
{
	mycore=c;
	id = Id;

	logId = mycore->getLogger()->createFile(nameClass,id);
	
	initialize = true;
	
	log(nameClass + " initialized");
	
	return logId;
}

/** Does nothing
	\return Always 0*/
int base::update()
{
	return 0;
}

/** Close the log and put base::initialize to false
	\return logger::closeFile()*/
int base::close()
{
	log(nameClass + " closed");
	initialize = false;
	return mycore->getLogger()->closeFile(logId);
}

int base::getId()
{
	return id;
}

/** Send text to the logger to log it in the proper file
	\param text text to log(pure text, time and \\n will be add letter)
	\return logger::write()*/
int base::log(stringc text)
{
	return mycore->getLogger()->write(logId,text);
}

bool base::isInit()
{
	return initialize;
}

